<template>
  <div class="tree-table-container">
    <div class="drag-box" ref="drag-box">
      <div class="drag-left">
        <div class="common-tree-container">
          <div class="common-tree-title">
            <i class="el-icon-menu"></i> 产品管理目录
          </div>
          <div class="common-tree-content">
            <!-- :render-content="renderContent" -->
            <el-tree :highlight-current="true" ref="tree" node-key="name" v-if="treeData.length" :data="treeData"
              :props="defaultProps" @node-click="handleNodeClick" default-expand-all>
            </el-tree>
          </div>
        </div>
      </div>
      <div class="drag-resize" title="收缩侧边栏">
        ⋮
      </div>
      <div class="drag-mid">
        <div class="common-table-container">
          <div class="bbsl-common-page">
            <div class="bbsl-table-search">
              <el-form v-model="queryParam" label-width="auto">
                <el-row :gutter="10">
                  <el-col :span="6">
                    <el-form-item label="产品编码">
                      <el-input maxlength="32" clearable placeholder="请输入产品编码" v-model="querys[0].value">
                      </el-input>
                    </el-form-item>
                  </el-col>
                  <el-col :span="6">
                    <el-form-item label="产品名称">
                      <el-input maxlength="64" clearable placeholder="请输入产品名称" v-model="querys[1].value">
                      </el-input>
                    </el-form-item>
                  </el-col>
                  <el-col :span="6">
                    <el-form-item label="设备类型">
                      <el-select clearable v-model="querys[2].value" placeholder="请选择设备类型">
                        <el-option v-for="item in deviceTypeList" :key="item.value" :label="item.name"
                          :value="item.value"></el-option>
                      </el-select>
                    </el-form-item>
                  </el-col>
                  <el-col :span="4">
                    <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
                    <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
                  </el-col>
                </el-row>
              </el-form>
            </div>
            <div class="bbsl-table-content" ref="contentPanel">
              <div class="bbsl-btn-content" ref="btnPanel">
                <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
                <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
                  <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"
                    style="margin-left: 10px" type="danger">删除
                  </el-button>
                </el-popconfirm>
              </div>
              <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
                :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
                :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="toProductDetails"
                @selection-change="handleSelectionChange">
                <!-- toProductDetails -->
                <el-table-column type="selection" width="55"></el-table-column>
                <el-table-column fixed type="index" width="55" label="序号"></el-table-column>

                <el-table-column width="100" prop="code" label="产品编码" show-overflow-tooltip>
                </el-table-column>
                <el-table-column prop="name" label="产品名称" show-overflow-tooltip min-width="110">
                </el-table-column>
                <el-table-column min-width="160" prop="fullName" label="所属分类" show-overflow-tooltip>
                </el-table-column>
                <el-table-column width="90" prop="isIntellect" label="智能分类" show-overflow-tooltip>
                </el-table-column>
                <el-table-column width="90" prop="deviceType" label="设备类型" show-overflow-tooltip>
                </el-table-column>
                <el-table-column prop="publishStatus" label="发布状态" show-overflow-tooltip width="100">
                  <template slot-scope="scope">
                    <div :class="{ statusActive: scope.row.publishStatus == 1 }">
                      {{ scope.row.publishStatus == 1 ? '已发布' : '未发布' }}
                    </div>
                  </template>
                </el-table-column>
                <el-table-column prop="icon" label="图标" show-overflow-tooltip width="60">
                  <template slot-scope="scope">
                    <svgIcon icon-style="icon" :icon-class="scope.row.icon" v-if="scope.row.icon"
                      style="font-size: 24px; vertical-align: middle; " />

                    <!-- <img v-if="scope.row.icon" class="avtar" :src="previewUrl + scope.row.icon"
                      alt="" /> -->
                  </template>
                </el-table-column>
                <el-table-column prop="" label="操作" show-overflow-tooltip>
                  <template #default="scope">
                    <el-button @click="handleRelease(scope.row)" size="small">
                      {{ scope.row.publishStatus == 0 ? '发布产品' : '下架产品' }}
                    </el-button>
                  </template>
                </el-table-column>
              </el-table>
              <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
                @size-change="handleSizeChange" @current-change="handleCurrentChange"
                :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
                :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
                :total="total"></el-pagination>
            </div>
          </div>
        </div>
      </div>
    </div>
    <productManageDialog @reload="reload" ref="formModal"></productManageDialog>
    <!-- 产品类型新增窗口 -->
    <productOrgDialog v-if="showFormDias" :pId="pId" :showFormDias="showFormDias" @refList="getTreen"
      @closeFormDiaos="closeFormDiaos" :titles="titles"></productOrgDialog>
    <!-- 产品类型修改窗口  -->
    <productOrgUpdateDialog v-if="showFormDiaUp" :pId="pId" :showFormDiaUp="showFormDiaUp" @refList="getTreen"
      @closeFormDiaoUp="closeFormDiaoUp" :titleUp="titleUp">
    </productOrgUpdateDialog>
  </div>
</template>
<script>
import {
  TableMixin
} from '@/mixins/tableMixin'
import {
  dragControllerDiv
} from '@/mixins/dragControllerDiv'
import productManage from '@/api/device/productManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import productOrgDialog from '@/views/Device/deviceManage/components/productOrgDialog'
import productOrgUpdateDialog from '@/views/Device/deviceManage/components/productOrgUpdateDialog'
import productManageDialog from '@/views/Device/deviceManage/components/productManageDialog'

export default {
  name: 'productManage',
  components: {
    productOrgDialog,
    productOrgUpdateDialog,
    productManageDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      titles: '',
      titleUp: '',
      tableData: [],
      showFormDias: false,
      showFormDiaUp: false, //修改产品类型
      treeData: [],
      defaultProps: {
        children: 'children',
        label: 'name'
      },
      previewUrl: window.context.portal + '/file/onlinePreviewController/v1/getFileById_', //图标预览
      treeNode: {
        code: '',
        id: '0',
        name: '产品管理',
        type: 0,
        children: []
      },
      pId: '',
      url: {
        delete: '/device/product/info/'
      }, // 删除产品信息
      querys: [{
        group: 'main',
        operation: 'LIKE',
        parentGroup: '',
        property: 'code',
        relation: 'AND',
        value: ''
      },
      {
        group: 'main',
        operation: 'EQUAL',
        parentGroup: '',
        property: 'name',
        relation: 'AND',
        value: ''
      },
      {
        group: 'main',
        operation: 'EQUAL',
        parentGroup: '',
        property: 'deviceType',
        relation: 'AND',
        value: ''
      },
      {
        group: 'main',
        operation: 'EQUAL',
        parentGroup: '',
        property: 'typeId',
        relation: 'AND',
        value: ''
      }
      ],
      deviceTypeList: [], //设备类型字段列表
      isIntellectList: [] //智能分类字段列表
    }
  },
  watch: {
    filterText(val) {
      this.$refs.tree.filter(val)
    }
  },
  created() {
    this.deviceTypeList = dictUtils.getDictItemsFromCache('sblx')
    this.isIntellectList = dictUtils.getDictItemsFromCache('znfl')
  },
  mounted() {
    dragControllerDiv()
    this.getTreen()
  },
  methods: {
    // 产品组织树查询
    getTreen() {
      productManage.productType().then(res => {
        this.treeData = res.value
        this.$set(this.treeData)
      })
    },
    toProductDetails(val) {
      let path = this.$route.path
      if (path.indexOf('frontPlat') !== -1) {
        this.$router.push({
          name: 'ProductDetails',
          query: {
            id: val.id,
            name: val.name
          }
        })
      } else {
        this.$router.push({
          name: 'ProductDetailsLink',
          query: {
            id: val.id,
            name: val.name
          }
        })
      }
    },
    // renderContent(h, {node, data, store}) {
    //   return (
    //     <span
    //       class="custom-tree-node"
    //       on-mouseover={() => {
    //         this.show = true
    //       }}
    //       on-mouseout={() => {
    //         this.show = false
    //       }}
    //     >
    //       <span>{data.name}</span>
    //       <span>
    //         <el-popover placement="bottom" width="55" trigger="hover">
    //           <el-button
    //             style="width:100%;border:0;margin:0;color:#606266;"
    //             size="mini"
    //             type="text"
    //             icon="el-icon-plus"
    //             on-click={() => this.append(data, 'son')}
    //           >
    //             新增
    //           </el-button>
    //           <el-button
    //             v-show={data.id !== '0'}
    //             style="width:100%;border:0;margin:0;color:#606266;"
    //             size="mini"
    //             type="text"
    //             icon="el-icon-edit"
    //             on-click={() => this.upDateinfo(data, '')}
    //           >
    //             修改
    //           </el-button>
    //           <el-button
    //             v-show={data.id !== '0'}
    //             style="width:100%;border:0;margin:0;color:#606266;"
    //             size="mini"
    //             icon="el-icon-delete"
    //             type="text"
    //             on-click={() => this.remove(data)}
    //           >
    //             删除
    //           </el-button>
    //           <i
    //             slot="reference"
    //             class="el-icon-more"
    //             // style="font-size: 15px;"
    //           ></i>
    //         </el-popover>
    //       </span>
    //     </span>
    //   )
    // },
    reload() {
      this.treeData = []
      this.$set(this.treeData)
      this.getTreen()
      this.loadData()
    },
    filterNode(value, data) {
      if (!value) return true
      return data.name.indexOf(value) !== -1
    },
    // 获取产品信息
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      productManage.productInfo(this.queryParam).then(res => {
        // console.log(res)
        this.total = res.total
        this.tableData = res.rows
        this.tableData.forEach(item => {
          let arr = item.fullName.split('/')
          for (let index = 0; index < arr.length; index++) {
            if (arr[index] == item.name) {
              return (item['fullName'] = arr[index - 1])
            }
          }
        })
        this.tableData.forEach(item => {
          this.isIntellectList.forEach(val => {
            if (item.isIntellect == val.value) {
              item['isIntellect'] = val.name
            }
          })
        })
        this.tableData.forEach(item => {
          this.deviceTypeList.forEach(val => {
            if (item.deviceType == val.value) {
              item['deviceType'] = val.name
            }
          })
        })
        this.$set(this.tableData)
        this.loading = false
      })
    },
    handleAdd() {
      if (this.treeNode.type == 0) {
        this.$message.warning('请选择产品类型！')
        return
      }
      this.$refs.formModal.add(this.treeNode)
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    append(data, type) {
      this.showFormDias = true
      if (type != 'father') {
        this.titles = '新增'
        this.showFormDias = true
        this.pId = data.id
      } else {
        this.titles = '新增'
        this.showFormDias = true
      }
    },
    upDateinfo(data, type) {
      this.titleUp = '修改'
      this.showFormDiaUp = true
      this.pId = data.id
    },
    // 关闭新增产品类型窗口
    closeFormDiaos() {
      this.showFormDias = false
      this.getTreen()
      this.loadData()
    },
    // 关闭修改产品类型窗口
    closeFormDiaoUp() {
      this.showFormDiaUp = false
      this.getTreen()
      this.loadData()
    },
    // 删除产品类型
    remove(data) {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning'
      })
        .then(() => {
          productManage
            .removeProductType(data.id)
            .then(res => {
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: '删除成功',
                  duration: 2000
                })
                this.queryParam.pageBean.page = 1
                this.loadData()
                this.getTreen()
                this.$set(this.treeData, this.treeData, this.treeData)
              }
            })
            .catch(res => {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80
              })
            })
        })
        .catch(() => {
        })
    },
    handleNodeClick(data) {
      this.treeNode = data
      if (data.id == '0') {
        this.querys[3].value = this.treeNode.code
        this.loadData(1)
      } else {
        this.querys[3].value = this.treeNode.id
        this.loadData(1)
      }
    },
    handleRelease(row) {
      // let params={
      // 	id:row.id,
      // 	publishStatus:row.publishStatus
      // }
      let publishStatus = row.publishStatus == 1 ? 0 : 1
      const formData = new FormData()
      formData.append('id', row.id)
      formData.append('publishStatus', publishStatus)
      const config = {
        headers: {
          'Content-Type': 'multipart/form-data'
        }
      }
      this.$http.post(window.context.portal + `/device/product/info/publish`, formData, config).then(res => {
        if (res.data.state) {
          this.$message.success(`${row.publishStatus == 0 ? '发布' : '下架'}成功`)
          this.loadData(1)
        }
      })


    }
  }
}
</script>
<style lang="scss" scoped>
.statusActive {
  color: blue;
}

.common-tree-container {
  width: 100% !important;
}

.common-tree-container ::v-deep .el-tree {
  border: none;
}

.tree-table-container ::v-deep .custom-tree-node span {
  font-size: 14PX !important;
}

.avtar {
  width: 24px;
  height: 24px;
}

::v-deep .el-tree-node>.el-tree-node__children {
  overflow: visible;
}
</style>
